@@ -14,9 +14,9 @@ brew install \
 brew link gettext --force
 
 # A workaround of https://gitlab.kitware.com/cmake/cmake/-/issues/23826
-for F in $(grep -l '(, weak)\?'  /usr/local/Cellar/cmake/*/share/cmake/Modules/GetPrerequisites.cmake); do
+for F in $(grep -l '(, weak)\?'  {/usr/local,/opt/homebrew}/Cellar/cmake/*/share/cmake/Modules/GetPrerequisites.cmake); do
   echo Patching $F...
-  # OSx sed does not support the -i option
+  # macOS sed does not support the -i option
   sed -e 's/(, weak)\?/(, (weak|reexport))?/' $F >${F}.new
   mv ${F}.new $F
 done
