@@ -185,11 +185,11 @@ GOHashType GOOrganController::GenerateCacheHash() {
   hash.Update(sizeof(GOSoundingPipe));
   hash.Update(sizeof(GOSoundReleaseAlignTable));
   hash.Update(BLOCK_HISTORY);
-  hash.Update(MAX_READAHEAD);
+  hash.Update(GOSoundAudioSection::getMaxReadAhead());
   hash.Update(SHORT_LOOP_LENGTH);
   GOSoundProvider::UpdateCacheHash(hash);
-  hash.Update(sizeof(audio_start_data_segment));
-  hash.Update(sizeof(audio_end_data_segment));
+  hash.Update(sizeof(GOSoundAudioSection::StartSegment));
+  hash.Update(sizeof(GOSoundAudioSection::EndSegment));
   return hash.getHash();
 }
 
