@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -20,7 +20,7 @@ class GOPistonControl : public GOPushbuttonControl,
 private:
   GOButtonControl *drawstop;
 
-  void ControlChanged(void *control);
+  void ControlChanged(GOControl *control) override;
 
 public:
   GOPistonControl(GOOrganModel &organModel);
