@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -13,6 +13,7 @@
 
 #include "gui/primitives/go_gui_utils.h"
 #include "help/GOHelpRequestor.h"
+#include "size/GOSizeKeeper.h"
 
 #include "GODialogCloser.h"
 #include "GODialogSizeSet.h"
@@ -30,7 +31,7 @@ private:
   static const wxString WX_EMPTY;
 
   const wxString m_name;
-  GOGUISizeKeeper &r_SizeKeeper;
+  GOSizeKeeper &r_SizeKeeper;
   wxSizer *p_ButtonSizer = nullptr;
 
   // For using in constructors only
@@ -117,12 +118,19 @@ protected:
    */
   virtual const wxString &GetHelpSuffix() const { return WX_EMPTY; }
 
+  virtual void ApplyAdditionalSizes(const GOAdditionalSizeKeeper &sizeKeeper) {}
+  virtual void CaptureAdditionalSizes(
+    GOAdditionalSizeKeeper &sizeKeeper) const {}
+
 public:
   bool Show(bool show = true) override {
-    if (show)
+    if (show) {
       r_SizeKeeper.ApplySizeInfo(*(DialogClass *)this);
-    else
+      ApplyAdditionalSizes(r_SizeKeeper);
+    } else {
       r_SizeKeeper.CaptureSizeInfo(*(DialogClass *)this);
+      CaptureAdditionalSizes(r_SizeKeeper);
+    }
     return DialogClass::Show(show);
   }
 
