@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -12,6 +12,8 @@
 #include <wx/bookctrl.h>
 #include <wx/panel.h>
 
+#include "size/GOAdditionalSizeKeeperProxy.h"
+
 #include "GODialogTab.h"
 
 GOTabbedDialog::GOTabbedDialog(
@@ -38,6 +40,34 @@ void GOTabbedDialog::AddTab(GODialogTab *tab) {
   AddTab(tab, tab->GetName(), tab->GetLabel());
 }
 
+void GOTabbedDialog::ApplyAdditionalSizes(
+  const GOAdditionalSizeKeeper &sizeKeeper) {
+  for (unsigned l = p_book->GetPageCount(), i = 0; i < l; i++) {
+    GODialogTab *tab = dynamic_cast<GODialogTab *>(p_book->GetPage(i));
+
+    if (tab) {
+      GOAdditionalSizeKeeperProxy proxy(
+        const_cast<GOAdditionalSizeKeeper &>(sizeKeeper), tab->GetName());
+
+      tab->ApplyAdditionalSizes(proxy);
+    }
+  }
+}
+
+void GOTabbedDialog::CaptureAdditionalSizes(
+  GOAdditionalSizeKeeper &sizeKeeper) const {
+  for (unsigned l = p_book->GetPageCount(), i = 0; i < l; i++) {
+    const GODialogTab *tab
+      = dynamic_cast<const GODialogTab *>(p_book->GetPage(i));
+
+    if (tab) {
+      GOAdditionalSizeKeeperProxy proxy(sizeKeeper, tab->GetName());
+
+      tab->CaptureAdditionalSizes(proxy);
+    }
+  }
+}
+
 const wxString &GOTabbedDialog::GetCurrTabName() const {
   return m_TabNames[p_book->GetSelection()];
 }
