@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -36,7 +36,7 @@ protected:
   void Init(GOConfigReader &cfg, wxString group);
   void Save(GOConfigWriter &cfg);
 
-  void ControlChanged(void *control);
+  void ControlChanged(GOControl *control) override;
 
 public:
   GOGUIControl(GOGUIPanel *panel, void *control);
