@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -98,11 +98,11 @@ void GOOrganModel::Load(GOConfigReader &cfg) {
   }
 
   unsigned NumberOfTremulants
-    = cfg.ReadInteger(ODFSetting, WX_ORGAN, wxT("NumberOfTremulants"), 0, 10);
+    = cfg.ReadInteger(ODFSetting, WX_ORGAN, wxT("NumberOfTremulants"), 0, 999);
   for (unsigned i = 0; i < NumberOfTremulants; i++) {
     m_tremulants.push_back(new GOTremulant(*this));
     m_tremulants[i]->Load(
-      cfg, wxString::Format(wxT("Tremulant%03d"), i + 1), -((int)(i + 1)));
+      cfg, wxString::Format(wxT("Tremulant%03d"), i + 1), i + 1);
   }
 
   for (unsigned i = 0; i < NumberOfWindchestGroups; i++)
@@ -205,12 +205,6 @@ void GOOrganModel::UpdateVolume() {
     m_windchests[i]->UpdateVolume();
 }
 
-GOWindchest *GOOrganModel::GetWindchest(unsigned index) {
-  return m_windchests[index];
-}
-
-unsigned GOOrganModel::GetWindchestGroupCount() { return m_windchests.size(); }
-
 unsigned GOOrganModel::AddWindchest(GOWindchest *windchest) {
   m_windchests.push_back(windchest);
   return m_windchests.size();
@@ -313,6 +307,25 @@ GOGeneralButtonControl *GOOrganModel::GetGeneral(unsigned index) {
   return m_generals[index];
 }
 
+void GOOrganModel::FillCoupledManualsForDivisional(
+  unsigned startManual, std::set<unsigned> &manualSet) const {
+  // protection against infinite recursion
+  if (manualSet.insert(startManual).second) {
+    // walk on the couplers
+    for (const GODivisionalCoupler *coupler : m_DivisionalCoupler)
+      for (auto otherManual : coupler->GetCoupledManuals(startManual))
+        FillCoupledManualsForDivisional(otherManual, manualSet);
+  }
+}
+
+std::set<unsigned> GOOrganModel::GetCoupledManualsForDivisional(
+  unsigned startManual) const {
+  std::set<unsigned> res;
+
+  FillCoupledManualsForDivisional(startManual, res);
+  return res;
+}
+
 void GOOrganModel::UpdateAllButtonsLight(
   GOButtonControl *buttonToLight, int manualIndexOnlyFor) {
   if (manualIndexOnlyFor < 0)
