@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2024 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -26,7 +26,8 @@ GOReferencePipe::GOReferencePipe(
     m_Filename() {}
 
 void GOReferencePipe::Load(
-  GOConfigReader &cfg, wxString group, wxString prefix) {
+  GOConfigReader &cfg, const wxString &group, const wxString &prefix) {
+  SetGroupAndPrefix(group, prefix);
   m_model->RegisterCacheObject(this);
   m_Filename = cfg.ReadStringTrim(ODFSetting, group, prefix);
   if (!m_Filename.StartsWith(wxT("REF:")))
@@ -56,10 +57,6 @@ void GOReferencePipe::Initialize() {
   m_ReferenceID = m_Reference->RegisterReference(this);
 }
 
-void GOReferencePipe::UpdateHash(GOHash &hash) {}
-
-const wxString &GOReferencePipe::GetLoadTitle() { return m_Filename; }
-
 void GOReferencePipe::VelocityChanged(
   unsigned velocity, unsigned old_velocity) {
   m_Reference->SetVelocity(velocity, m_ReferenceID);
